function struct2fitshead, hdrstr, use_sxaddpar=use_sxaddpar, comments=comments
;+
;   Name: struct2fitshead
;
;   Purpose: Map FITS Header-Structure structure back-> fits header (strarr)
;
;   Input Parameters:
;      hdrstr - IDL structure to map into fits header (ex: output of mreadfits)
;
;   Output:
;      function returns FITS header derived from structure
;
;   Calling Sequence:
;      header=struct2fitshead(structure)
;
;   Calling Example:
;	mreadfits,f,hdr,data
;	ahdr = struct2fitshead(hdr(0))
;	writefits,"new-"+f(0),f(0),ahdr
;
;   History:
;      Craig DeForrest w/S.L.Freeland - 11-apr-1997
;      2-March-1998 - S.L.Freeland add some error checking...
;                     add /USE_SXADDPAR keyword (eventual default?)
;                     (default if NAXIS etc missing - just do it)
;      6-March-1998 - S.L.Freeland - add COMMENTS input keyword
;
;   Calls:
;      fxaddpar, sxaddpar
;
;   LIMITATIONS: PROTOTYPE (functional) 
;                Only works on a single header at a time -- may not be (easily)
;                vectorized.
;-
common struct2fitshead_blk, lastproc

if not data_chk(hdrstr,/struct) then begin
   box_message,['Structure required','IDL> header=struct2fitshead(structure)']
   return,''
endif

;  validity check (sxaddpar permits 'malformed' headers, ok in many applications
vindex=where(tag_index(hdrstr,str2arr('BITPIX,NAXIS,NAXIS1')) eq -1,ivcnt)
use_sxaddpar=keyword_set(use_sxaddpar) or ivcnt gt 0 
addproc=(['fxaddpar','sxaddpar'])(use_sxaddpar)  ; choose procedure

if n_elements(lastproc) eq 0 then lastproc=''
if lastproc ne addproc then begin
   box_message,'struct2fitshead - using procedure: ' + addproc
   lastproc=addproc
endif  

if addproc eq 'sxaddpar' then ohdr=strarr(1)              ; diff initial val

tags = tag_names(hdrstr)
ntags=n_elements(tags)

coms=strarr(ntags)
if n_elements(comments) eq ntags then coms=comments       ; user supplied

for i=0,n_elements(tags)-1 do begin
   value=hdrstr.(i)
   if n_elements(value) gt 1 then begin                   ; comment&history
      nonnulls=where(strtrim(value,2) ne '',nncnt)
      for j=0,nncnt-1 do call_procedure,addproc,ohdr,tags(i),(hdrstr.(i))(nonnulls(j))
   endif else begin
      value=hdrstr.(i)        
      if data_chk(value,/type) eq 1 then value=fix(value)
      call_procedure, addproc, ohdr, tags(i),value, coms(i)
   endelse
endfor

return,ohdr
end


